# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emessages.proto\x12\x1eorg.couchers.api.conversations\x1a\x1fgoogle/protobuf/timestamp.proto\"\"\n\x12MessageContentText\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x1b\n\x19MessageContentChatCreated\"\x1a\n\x18MessageContentChatEdited\"3\n\x19MessageContentUserInvited\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"\x18\n\x16MessageContentUserLeft\"5\n\x1bMessageContentUserMadeAdmin\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"8\n\x1eMessageContentUserRemovedAdmin\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"3\n\x19MessageContentUserRemoved\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"k\n&MessageContentHostRequestStatusChanged\x12\x41\n\x06status\x18\x01 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\"\xf5\x06\n\x07Message\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x61uthor_user_id\x18\x02 \x01(\x04\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x04text\x18\x04 \x01(\x0b\x32\x32.org.couchers.api.conversations.MessageContentTextH\x00\x12Q\n\x0c\x63hat_created\x18\x05 \x01(\x0b\x32\x39.org.couchers.api.conversations.MessageContentChatCreatedH\x00\x12O\n\x0b\x63hat_edited\x18\x06 \x01(\x0b\x32\x38.org.couchers.api.conversations.MessageContentChatEditedH\x00\x12Q\n\x0cuser_invited\x18\x07 \x01(\x0b\x32\x39.org.couchers.api.conversations.MessageContentUserInvitedH\x00\x12K\n\tuser_left\x18\x08 \x01(\x0b\x32\x36.org.couchers.api.conversations.MessageContentUserLeftH\x00\x12V\n\x0fuser_made_admin\x18\t \x01(\x0b\x32;.org.couchers.api.conversations.MessageContentUserMadeAdminH\x00\x12\\\n\x12user_removed_admin\x18\n \x01(\x0b\x32>.org.couchers.api.conversations.MessageContentUserRemovedAdminH\x00\x12m\n\x1bhost_request_status_changed\x18\x0b \x01(\x0b\x32\x46.org.couchers.api.conversations.MessageContentHostRequestStatusChangedH\x00\x12\\\n\x17group_chat_user_removed\x18\x0c \x01(\x0b\x32\x39.org.couchers.api.conversations.MessageContentUserRemovedH\x00\x42\t\n\x07\x63ontent*\xbe\x01\n\x11HostRequestStatus\x12\x1f\n\x1bHOST_REQUEST_STATUS_PENDING\x10\x00\x12 \n\x1cHOST_REQUEST_STATUS_ACCEPTED\x10\x01\x12 \n\x1cHOST_REQUEST_STATUS_REJECTED\x10\x02\x12!\n\x1dHOST_REQUEST_STATUS_CONFIRMED\x10\x03\x12!\n\x1dHOST_REQUEST_STATUS_CANCELLED\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HOSTREQUESTSTATUS']._serialized_start=1419
  _globals['_HOSTREQUESTSTATUS']._serialized_end=1609
  _globals['_MESSAGECONTENTTEXT']._serialized_start=83
  _globals['_MESSAGECONTENTTEXT']._serialized_end=117
  _globals['_MESSAGECONTENTCHATCREATED']._serialized_start=119
  _globals['_MESSAGECONTENTCHATCREATED']._serialized_end=146
  _globals['_MESSAGECONTENTCHATEDITED']._serialized_start=148
  _globals['_MESSAGECONTENTCHATEDITED']._serialized_end=174
  _globals['_MESSAGECONTENTUSERINVITED']._serialized_start=176
  _globals['_MESSAGECONTENTUSERINVITED']._serialized_end=227
  _globals['_MESSAGECONTENTUSERLEFT']._serialized_start=229
  _globals['_MESSAGECONTENTUSERLEFT']._serialized_end=253
  _globals['_MESSAGECONTENTUSERMADEADMIN']._serialized_start=255
  _globals['_MESSAGECONTENTUSERMADEADMIN']._serialized_end=308
  _globals['_MESSAGECONTENTUSERREMOVEDADMIN']._serialized_start=310
  _globals['_MESSAGECONTENTUSERREMOVEDADMIN']._serialized_end=366
  _globals['_MESSAGECONTENTUSERREMOVED']._serialized_start=368
  _globals['_MESSAGECONTENTUSERREMOVED']._serialized_end=419
  _globals['_MESSAGECONTENTHOSTREQUESTSTATUSCHANGED']._serialized_start=421
  _globals['_MESSAGECONTENTHOSTREQUESTSTATUSCHANGED']._serialized_end=528
  _globals['_MESSAGE']._serialized_start=531
  _globals['_MESSAGE']._serialized_end=1416
# @@protoc_insertion_point(module_scope)
